%define ALD_Ver		1.2.4

Name:         alsa-utils

License:      GPL
Summary:      Advanced Linux Sound Architecture (ALSA) - Utils
Group:        System/Libraries
Version:      1.0.28
Release:      0
URL: http://www.alsa-project.org

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh
Source2: KDE_Beep_RimShot.wav

%define DestDir		/Multimedia
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 0
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin
%define target_  %{target}-

%define __os_install_post %{nil}

%define cross_prefix	%{csysdir}%{_prefix}
%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
# ------------------- description ------------------------------------
%description
Advanced Linux Sound Architecture (ALSA) - Utils
#-------------------------------
%package tools
Summary:      The %{name} packages tools
Group:        System/Tools
Requires: %{name}
%description tools
The %{name} packages tools
#-------------------------------
%package midi
Summary:      The %{name} packages midi files
Group:        System/Tools
Requires: %{name}
%description midi
The %{name} packages midi files
#-------------------------------
%package sounds
Summary:      The %{name} packages all sounds files
Group:        System/Tools
Requires: %{name}
%description sounds
The %{name} packages all sounds files

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=" "

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
LDFLAGS=`case $GCC_VER_STR in 4.[56789].*) echo -static-libgcc ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif

CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -std=gnu99 -D_GNU_SOURCE"
CXXFLAGS="$OPTFLAGS"

LDFLAGS="$LDFLAGS -Wl,--gc-sections"

export CC=%{target_}gcc

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-rpath \
	--disable-alsatest \
	--disable-nls \
	--disable-xmlto \
	--with-testsound=/usr/share/sounds/alsa/KDE_Beep_RimShot.wav \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp -a README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

cp %SOURCE2 $RPM_BUILD_ROOT/%{_datadir}/sounds/alsa/

rm -fr $RPM_BUILD_ROOT%{_mandir}/fr
rm -fr $RPM_BUILD_ROOT%{_mandir}/man7

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-tools-$SE $DD/%{name}-tools-$DE
  mv %{name}-midi-$SE $DD/%{name}-midi-$DE
  mv %{name}-sounds-$SE $DD/%{name}-sounds-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%files
%{_bindir}/alsamixer
%{_bindir}/amixer
%{_bindir}/aplay
%{_bindir}/arecord
%{_bindir}/iecset
%{_sbindir}
%{_mandir}/man1/alsactl.1.gz
%{_mandir}/man1/alsamixer.1.gz
%{_mandir}/man1/amixer.1.gz
%{_mandir}/man1/aplay.1.gz
%{_mandir}/man1/arecord.1.gz
%{_mandir}/man1/iecset.1.gz
%{_mandir}/man8
%{_datadir}/alsa
%{_datadir}/sounds/alsa/KDE_Beep_RimShot.wav
/%{_lib}/udev/rules.d/90-alsa-restore.rules
/var
%{docdir}

%files tools
%{_bindir}/aconnect
%{_bindir}/alsaloop
%{_bindir}/alsaucm
%{_bindir}/aseqdump
%{_bindir}/aseqnet
%{_bindir}/speaker-test
%{_mandir}/man1/aconnect.1.gz
%{_mandir}/man1/alsaloop.1.gz
%{_mandir}/man1/aseqdump.1.gz
%{_mandir}/man1/aseqnet.1.gz
%{_mandir}/man1/speaker-test.1.gz

%files midi
%{_bindir}/amidi
%{_bindir}/aplaymidi
%{_bindir}/arecordmidi
%{_mandir}/man1/amidi.1.gz
%{_mandir}/man1/aplaymidi.1.gz
%{_mandir}/man1/arecordmidi.1.gz

%files sounds
%{_datadir}/sounds/alsa/Front_Center.wav
%{_datadir}/sounds/alsa/Front_Left.wav
%{_datadir}/sounds/alsa/Front_Right.wav
%{_datadir}/sounds/alsa/Noise.wav
%{_datadir}/sounds/alsa/Rear_Center.wav
%{_datadir}/sounds/alsa/Rear_Left.wav
%{_datadir}/sounds/alsa/Rear_Right.wav
%{_datadir}/sounds/alsa/Side_Left.wav
%{_datadir}/sounds/alsa/Side_Right.wav
